DocxParagraph class

Implemented types

Constructors

DocxParagraph({required List<DocxRun> runs, String? styleId, String? alignment, bool isHeading = false, int headingLevel = 0, String? listType, int listLevel = 0, int? listItemNumber})

Properties

alignment String?
final
hashCode int
The hash code for this object.
no setterinherited
headingLevel int
final
isEmpty bool
no setter
isHeading bool
final
listItemNumber int?
final
listLevel int
final
listType String?
final
runs List<DocxRun>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
styleId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited