DocxParser class

Constructors

DocxParser()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

parse(Uint8List bytes) DocxDocument
resolveStyle(Map<String, DocxStyle> styles, String? styleId) DocxStyle?
Resolve style inheritance chain (basedOn).